#
# spec file for package python3-cairo
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define pyname  cairo
Name:           python3-%{pyname}
%define modname py%{pyname}
Version:        1.10.1~git20121222.5a45b0b
Release:        4.5
Summary:        Python Bindings for Cairo
License:        LGPL-3.0
Group:          Development/Libraries/Python
# FIXME: on update, check if we still need to manually remove the byte-code in %%install
Url:            https://cgit.freedesktop.org/pycairo
Source:         %{modname}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM pycairo-1.10.0-80_fix-pickle.patch bfo#91561 - Fix waf pickling on Python 3.5
Patch10:        pycairo-1.10.0-80_fix-pickle.patch
# PATCH-FIX-UPSTREAM pycairo-1.10.0-81_pickling-again.patch bfo#91561 - Further waf pickling on Python 3.5
Patch11:        pycairo-1.10.0-81_pickling-again.patch
BuildRequires:  cairo-devel
# Needed to have the modules for different hash algorithms; python3-devel only brings in python3-base
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Python bindings for the Cairo vector graphics library.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       cairo-devel
Requires:       python3-devel

%description devel
Development libraries and headers needed to build 
software using %{name}

%prep
%setup -q -n %{modname}-%{version}

# Patch bundled-in waf.
# First, run waf to extract its library.
PYTHON=python3 python3 waf --help > /dev/null

# Second, enter the extracted directory to do the patches.
# The directory name depends on the exact waf version,
# which we don't know ahead-of-time, so we can't put it
# in the patch directly.
pushd .waf3-*
%patch10 -p1 
%patch11 -p1
popd

%build
export PYTHON=python3 
python3 ./waf configure --prefix=%{_prefix} --libdir=%{_libdir}
python3 ./waf build

%install
python3 ./waf install --destdir=%{buildroot}
# waf is broken and generated byte-code that references the build root, see http://code.google.com/p/waf/issues/detail?id=986
rm %{buildroot}%{python3_sitearch}/%{pyname}/*.py[co]

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING.LESSER NEWS README
%{python3_sitearch}/%{pyname}/

%files devel
%defattr(-,root,root)
%{_includedir}/%{modname}/
%{_libdir}/pkgconfig/py3%{pyname}.pc

%changelog
* Tue Jun  7 2016 i@marguerite.su
- pycairo didn't see new release for 4 years, so git snapshot
  is reasonable.
- update to version 1.10.1~git20121222.5a45b0b:
  * Add support for RecordingSurface
  * Create a setup.py
  * Update tests
  * Implement ImageSurface.get_data()
  * Implement ImageSurface.create_for_data()
  * Remove option to use xpyb since it does not currently support Python 3,
    and the .pc file name conflicts with the Python 2 version.
  * Add some new constants, methods and functions
  * Add support for cairo_region_t
  * Update waf to 1.7.8
  * Correct the pycairo version number in config.h
- drop waf-py34.patch, upstreamed
* Wed May 25 2016 idonmez@suse.com
- Update to GNOME 3.20.2 FATE#318572
* Wed Oct 21 2015 toddrme2178@gmail.com
- Add pycairo-1.10.0-80_fix-pickle.patch and
  pycairo-1.10.0-81_pickling-again.patch
  These fix pickling issues in the bundled waf buildsystem on
  python 3.5.
  These patches are being used in various other distros,
  including gentoo, debian, abd ubuntu.
  See:
  https://bugs.freedesktop.org/show_bug.cgi?id=91561
  https://gitweb.gentoo.org/repo/gentoo.git/tree/dev-python/pycairo/files/pycairo-1.10.0-80_fix-pickle.patch
  https://gitweb.gentoo.org/repo/gentoo.git/tree/dev-python/pycairo/files/pycairo-1.10.0-81_pickling-again.patch
- Reformat waf-py34.patch
- Improve waf patching process
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove python(abi) requirement
* Mon Feb 10 2014 jmatejek@suse.com
- Add waf-py34.patch: patch waf to work correctly with python 3.4
* Thu Nov 22 2012 toddrme2178@gmail.com
- Remove openSUSE 11.4 spec file workarounds
* Fri May  4 2012 toddrme2178@gmail.com
- Fix rpmlint warnings
- Small spec file cleanups
* Fri Apr 27 2012 toddrme2178@gmail.com
- Fix building on openSUSE 11.4 x86_64
* Thu Apr 26 2012 toddrme2178@gmail.com
- Fix building of python 3 version on openSUSE 11.4
* Fri Sep 30 2011 vuntz@opensuse.org
- Add python3 BuildRequires, since the hash algorithm are not in
  python3-base anymore.
- Use %%{python3_sitearch} now that it's defined, instead of our own
  custom macro.
- Change python3 Requires to python(abi) = %%py3_ver, which is
  saner.
* Fri Jun 17 2011 vuntz@opensuse.org
- Change python3-base Requires to python3, since python3-base is
  not in Factory yet.
* Fri Jun 17 2011 vuntz@opensuse.org
- Initial package (version 1.10.0).
